import { Context } from "./context";
import * as Inputs from "./inputs";
import { DrawHelperCore } from "@bitbybit-dev/core";
import { JSCADText } from "@bitbybit-dev/jscad-worker";
import { Vector } from "@bitbybit-dev/base";
import { JSCADWorkerManager } from "@bitbybit-dev/jscad-worker";
import { ManifoldWorkerManager } from "@bitbybit-dev/manifold-worker";
import { OCCTWorkerManager } from "@bitbybit-dev/occt-worker";
import * as THREEJS from "three";
export declare class DrawHelper extends DrawHelperCore {
    private readonly context;
    private readonly solidText;
    readonly vector: Vector;
    private readonly jscadWorkerManager;
    private readonly manifoldWorkerManager;
    private readonly occWorkerManager;
    private usedMaterials;
    constructor(context: Context, solidText: JSCADText, vector: Vector, jscadWorkerManager: JSCADWorkerManager, manifoldWorkerManager: ManifoldWorkerManager, occWorkerManager: OCCTWorkerManager);
    drawManifoldsOrCrossSections(inputs: Inputs.Manifold.DrawManifoldsOrCrossSectionsDto<Inputs.Manifold.ManifoldPointer | Inputs.Manifold.CrossSectionPointer, THREEJS.MeshPhysicalMaterial>): Promise<THREEJS.Group>;
    drawManifoldOrCrossSection(inputs: Inputs.Manifold.DrawManifoldOrCrossSectionDto<Inputs.Manifold.ManifoldPointer | Inputs.Manifold.CrossSectionPointer, THREEJS.MeshPhysicalMaterial>): Promise<THREEJS.Group>;
    drawShape(inputs: Inputs.OCCT.DrawShapeDto<Inputs.OCCT.TopoDSShapePointer>): Promise<THREEJS.Group>;
    drawShapes(inputs: Inputs.OCCT.DrawShapesDto<Inputs.OCCT.TopoDSShapePointer>): Promise<THREEJS.Group>;
    drawSolidOrPolygonMesh(inputs: Inputs.JSCAD.DrawSolidMeshDto<THREEJS.Group>): Promise<THREEJS.Group>;
    drawSolidOrPolygonMeshes(inputs: Inputs.JSCAD.DrawSolidMeshesDto<THREEJS.Group>): Promise<THREEJS.Group>;
    drawPolylinesWithColours(inputs: Inputs.Polyline.DrawPolylinesDto<THREEJS.Group>): THREEJS.Group<THREEJS.Object3DEventMap>;
    drawPoint(inputs: Inputs.Point.DrawPointDto<THREEJS.Group>): THREEJS.Group;
    drawPolylineClose(inputs: Inputs.Polyline.DrawPolylineDto<THREEJS.Group>): THREEJS.Group;
    drawPolyline(mesh: THREEJS.Group, pointsToDraw: Inputs.Base.Point3[], updatable: boolean, size: number, opacity: number, colours: string | string[]): THREEJS.Group;
    drawCurve(inputs: Inputs.Verb.DrawCurveDto<THREEJS.Group>): THREEJS.Group;
    drawPoints(inputs: Inputs.Point.DrawPointsDto<THREEJS.Group>): THREEJS.Group;
    updatePointsInstances(group: THREEJS.Group, positions: Inputs.Base.Point3[]): void;
    drawCurves(inputs: Inputs.Verb.DrawCurvesDto<THREEJS.Group>): THREEJS.Group;
    drawSurfacesMultiColour(inputs: Inputs.Verb.DrawSurfacesColoursDto<THREEJS.Group>): THREEJS.Group;
    private createPointSpheresMesh;
    createOrUpdateSurfacesMesh(meshDataConverted: {
        positions: number[];
        indices: number[];
        normals: number[];
        uvs?: number[];
    }[], group: THREEJS.Group, updatable: boolean, material: THREEJS.MeshPhysicalMaterial, addToScene: boolean, hidden: boolean): THREEJS.Group;
    drawSurface(inputs: Inputs.Verb.DrawSurfaceDto<THREEJS.Group>): THREEJS.Group;
    private parseFaces;
    private makeMesh;
    private createMesh;
    private handleDecomposedMesh;
    private drawPolylines;
    private createLineGeometry;
    private handleDecomposedManifold;
    private deleteFaceMaterialForWorker;
}
